# Retrieves only metadata from pages
Q_PAGE_META = """
current_page
has_more_pages
from
to
data {{
    {dataFields}
}}
"""
